BackdoorFlutter class abstract

BackdoorFlutter Class Provides provides method to check payment status and act accordingly

it provides 2 methods

  1. init to initialize configuration
  2. checkStatus to check the status

Constructors

BackdoorFlutter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkStatus({Map<String, dynamic>? httpHeaders, Map<String, dynamic>? httpQueryParameters, Map<String, dynamic>? httpRequestBody, String httpMethod = 'GET', required OnException onException, required OnUnhandled onUnhandled, OnAppNotFound? onAppNotFound, OnPaid? onPaid, OnUnPaid? onUnPaid, OnLimitedLaunch? onLimitedLaunch, OnLimitedLaunchExceeded? onLimitedLaunchExceeded, OnTrial? onTrial, OnTrialWarning? onTrialWarning, OnTrialEnded? onTrialEnded, OnTargetVersionMisMatch? onTargetVersionMisMatch, bool useCachedConfigOnNetworkException = true}) Future<void>
Checks the status of the application by retrieving and validating payment model data.
decrementCount() Future<void>
Decrements the launch count for the application.
init({String? jsonUrl, String? appName, double? version, bool showApiLogs = true, bool autoDecrementLaunchCount = true}) Future<void>
Initializes the application configuration.