BackdoorFlutterExceptionType enum
Enumeration representing various types of exceptions that can occur in the Backdoor application.
Values
- VALUE_NOT_FOUND → const BackdoorFlutterExceptionType
-
Indicates that a required value was not found.
- NETWORK_EXCEPTION → const BackdoorFlutterExceptionType
-
Indicates that a network-related exception occurred.
- UNKNOWN → const BackdoorFlutterExceptionType
-
Indicates an unknown exception that does not fit other categories.
- CONFIGURATION_EXCEPTION → const BackdoorFlutterExceptionType
-
Indicates a configuration-related exception.
- UNKNOWN_PAYMENT_STATUS → const BackdoorFlutterExceptionType
-
Indicates an unknown payment status.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BackdoorFlutterExceptionType> - A constant List of the values in this enum, in order of their declaration.