BackdoorPaymentModel class sealed

Represents the payment model for a backdoor application.

This model includes the payment status and configuration details for an application.

Annotations
  • @freezed

Constructors

BackdoorPaymentModel({@JsonKey.new(name: 'status') PaymentStatus? status, @JsonKey.new(name: 'target_version') double? targetVersion, @Default.new(false) @JsonKey.new(name: 'should_check_after_paid') bool shouldCheckAfterPaid, @Default.new(false) @JsonKey.new(name: 'check_during_trial') bool checkDuringTrial, @JsonKey.new(name: 'expire_date') DateTime? expireDateTime, @JsonKey.new(name: 'warning_date') DateTime? warningDate, @Default.new(true) @JsonKey.new(name: 'strict_max_launch') bool strictMaxLaunch, @JsonKey.new(name: 'max_launch') int? maxLaunch, @JsonKey.new(name: 'developer_details') Map<String, dynamic>? developerDetails, @JsonKey.new(name: 'additional_fields') Map<String, dynamic>? additionalFields})
Creates an instance of BackdoorPaymentModel.
const
factory
BackdoorPaymentModel.fromJson(Map<String, dynamic> json)
Creates a BackdoorPaymentModel from a JSON map.
factory

Properties

additionalFields Map<String, dynamic>?
no setterinherited
checkDuringTrial bool
no setterinherited
copyWith → $BackdoorPaymentModelCopyWith<BackdoorPaymentModel>
Create a copy of BackdoorPaymentModel with the given fields replaced by the non-null parameter values.
no setterinherited
developerDetails Map<String, dynamic>?
no setterinherited
expireDateTime DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxLaunch int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldCheckAfterPaid bool
no setterinherited
status PaymentStatus?
no setterinherited
strictMaxLaunch bool
no setterinherited
targetVersion double?
no setterinherited
warningDate DateTime?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BackdoorPaymentModel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited