OnTargetVersionMisMatch typedef

OnTargetVersionMisMatch = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, double targetVersion, double configuredVersion)

Callback type for handling target version mismatches.

This function is invoked when there is a version mismatch between the target version and the configured version, providing the payment model, the target version, and the configured version.

Implementation

typedef OnTargetVersionMisMatch = Function(
  BackdoorPaymentModel backdoorPaymentModel,
  double targetVersion,
  double configuredVersion,
);