OnTrialEnded typedef

OnTrialEnded = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, DateTime expiryDate)

Callback type for handling the end of a trial period.

This function is invoked when the trial period has ended, providing the payment model and the trial expiry date.

Implementation

typedef OnTrialEnded = Function(
  BackdoorPaymentModel backdoorPaymentModel,
  DateTime expiryDate,
);