OnTrialWarning typedef

OnTrialWarning = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, DateTime expiryDate, DateTime warningDate)

Callback type for handling trial warnings.

This function is invoked to notify about an impending trial expiry, providing the payment model, the trial expiry date, and the warning date.

Implementation

typedef OnTrialWarning = Function(
  BackdoorPaymentModel backdoorPaymentModel,
  DateTime expiryDate,
  DateTime warningDate,
);