OnUnPaid typedef

OnUnPaid = dynamic Function(BackdoorPaymentModel backdoorPaymentModel)

Callback type for handling unpaid application status.

This function is invoked when the application is in an unpaid state, providing the relevant payment model.

Implementation

typedef OnUnPaid = Function(BackdoorPaymentModel backdoorPaymentModel);