OnUnhandled typedef
OnUnhandled =
dynamic Function(OnUnhandledReason reason, BackdoorPaymentModel? backdoorPaymentModel)
Callback type for handling unhandled cases.
This function is invoked when an unexpected situation occurs, providing the reason for the unhandled case and the associated payment model.
Implementation
typedef OnUnhandled = Function(
OnUnhandledReason reason,
BackdoorPaymentModel? backdoorPaymentModel,
);