OnUnhandledReason enum

Enumeration representing various reasons for unhandled cases. when OnUnhandled is invoked

Inheritance
Available extensions

Values

Indicates that the application is in a paid state.

UNPAID → const OnUnhandledReason

Indicates that the application is in an unpaid state.

APP_NOT_FOUND_IN_JSON → const OnUnhandledReason

Indicates that the application was not found in the JSON configuration.

LIMITED_LAUNCH → const OnUnhandledReason

Indicates that the application is in a limited launch state.

LIMITED_LAUNCH_EXCEEDED → const OnUnhandledReason

Indicates that the application has exceeded its allowed launch count.

TRIAL_WARNING → const OnUnhandledReason

Indicates a warning for the impending end of a trial period.

TRIAL_ENDED → const OnUnhandledReason

Indicates that the trial period has ended.

TRIAL → const OnUnhandledReason

Indicates that the application is currently in a trial state.

EXCEPTION → const OnUnhandledReason

Indicates that an exception occurred during operation.

TARGET_VERSION_MISMATCH → const OnUnhandledReason

Indicates a mismatch between the target version and the configured version.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OnUnhandledReason>
A constant List of the values in this enum, in order of their declaration.