backdoor_flutter library
A Dart library for the Backdoor Flutter application.
This library provides functionality for managing payment statuses, handling exceptions, and working with application configuration.
Classes
- BackdoorFlutter
- BackdoorFlutter Class Provides provides method to check payment status and act accordingly
- BackdoorPaymentApiResponseModel
- Represents the API response model for backdoor payment status.
- BackdoorPaymentModel
- Represents the payment model for a backdoor application.
Enums
- BackdoorFlutterExceptionType
- Enumeration representing various types of exceptions that can occur in the Backdoor application.
- OnUnhandledReason
- Enumeration representing various reasons for unhandled cases. when OnUnhandled is invoked
- PaymentStatus
- Enumeration representing the possible payment statuses of an application.
Typedefs
- OnAppNotFound = dynamic Function()
- Callback type for when the application is not found.
- OnException = dynamic Function(BackdoorFlutterException exception)
- Callback type for handling exceptions.
- OnLimitedLaunch = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, int currentCount)
- Callback type for handling limited launch scenarios.
- OnLimitedLaunchExceeded = dynamic Function(BackdoorPaymentModel backdoorPaymentModel)
- Callback type for when the limited launch is exceeded.
- OnPaid = dynamic Function(BackdoorPaymentModel backdoorPaymentModel)
- Callback type for handling paid application status.
- OnTargetVersionMisMatch = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, double targetVersion, double configuredVersion)
- Callback type for handling target version mismatches.
- OnTrial = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, DateTime expiryDate, DateTime? warningDate)
- Callback type for handling trial periods.
- OnTrialEnded = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, DateTime expiryDate)
- Callback type for handling the end of a trial period.
- OnTrialWarning = dynamic Function(BackdoorPaymentModel backdoorPaymentModel, DateTime expiryDate, DateTime warningDate)
- Callback type for handling trial warnings.
- OnUnhandled = dynamic Function(OnUnhandledReason reason, BackdoorPaymentModel? backdoorPaymentModel)
- Callback type for handling unhandled cases.
- OnUnPaid = dynamic Function(BackdoorPaymentModel backdoorPaymentModel)
- Callback type for handling unpaid application status.
Exceptions / Errors
- BackdoorFlutterException
- Custom exception class for handling errors in the Backdoor application.