BackdoorPaymentApiResponseModel class sealed
Represents the API response model for backdoor payment status.
This model encapsulates the data structure returned by the payment status API, including a map of application payment models.
- Annotations
-
- @freezed
Constructors
-
BackdoorPaymentApiResponseModel({@JsonKey.new(name: 'apps') Map<
String, BackdoorPaymentModel> ? apps}) -
Creates an instance of BackdoorPaymentApiResponseModel.
constfactory
-
BackdoorPaymentApiResponseModel.fromJson(Map<
String, dynamic> json) -
Creates a BackdoorPaymentApiResponseModel from a JSON map.
factory
Properties
-
apps
→ Map<
String, BackdoorPaymentModel> ? -
no setterinherited
-
copyWith
→ $BackdoorPaymentApiResponseModelCopyWith<
BackdoorPaymentApiResponseModel> -
Create a copy of BackdoorPaymentApiResponseModel
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BackdoorPaymentApiResponseModel to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited