OnAppNotFound typedef
OnAppNotFound =
dynamic Function()
Callback type for when the application is not found.
This function is called when the application cannot be located in the configuration.
Implementation
typedef OnAppNotFound = Function();