OnLimitedLaunchExceeded typedef
OnLimitedLaunchExceeded =
dynamic Function(BackdoorPaymentModel backdoorPaymentModel)
Callback type for when the limited launch is exceeded.
This function is called when the application has exceeded its allowed launch count, providing the relevant payment model.
Implementation
typedef OnLimitedLaunchExceeded = Function(
BackdoorPaymentModel backdoorPaymentModel,
);