PaymentStatus enum
Enumeration representing the possible payment statuses of an application.
Values
- PAID → const PaymentStatus
-
Indicates that the application is in a paid state.
- UNPAID → const PaymentStatus
-
Indicates that the application is in an unpaid state.
- ALLOW_LIMITED_LAUNCHES → const PaymentStatus
-
Indicates that the application allows limited launches.
- ON_TRIAL → const PaymentStatus
-
Indicates that the application is currently on a trial period.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PaymentStatus> - A constant List of the values in this enum, in order of their declaration.